*12345678901234567890123456789012345678901234567890123456789012345678901234567890
capture log close
clear all

*	************************************************************************
* 	File-Name: 	AklinEAREAnalysis.do
*	Date:  		11/20/2012 (first version); 05/20/2015 (last version)
*	Author: 	Michal Aklin
*	Data Used:  AklinEAREData.dta
*	Purpose:   	.do file to replicate the results in:
*				Aklin, Michal. 2015. "Re-exploring the Trade and Environment 
*				Nexus Through the Diffusion of Pollution." Environmental and
*				Resource Economics.
*
*	Note:		This do file should only require few changes (e.g. path to
*				dataset).
*				Notice that the file may contain extra tables and figures.
*
*	Structure:	1. Dataset
*				2. Summary stats (Table 1)
*				3. Spatial models (Table 2 and 3)
*				4. Matching (Table 4)
*				5. Figure 1
*	************************************************************************


*	************************************************************************
*	1. Dataset
*	************************************************************************

*	Change the path as appropriate
use "./AklinEAREData.dta", clear

*	************************************************************************
*	2. Summary statistics. TABLE 1
*	************************************************************************

quiet xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year aklin_co2_norowst, fe
estpost summarize co2_capita_cdiac aklin_co2_norowst aklin_co2_rowst aklin_gdpcap_norowst aklin_gdpcap_rowst gdpcapk gdpcap2k polity2 industry_pcgdp_wdi service_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp opec_membership impabcap if e(sample) == 1

esttab using "./rr2table1.tex", ///
	cells("mean(fmt(3)) sd(fmt(3)) min(fmt(0)) max(fmt(0)) count(fmt(0))") ///
	substitute(m$ m\\$)	///
	nonumber label replace
eststo clear


*	************************************************************************
*	3. Spatial Tables and Figures
*	************************************************************************

*	************************************************************************
*	Table 2
*	************************************************************************

eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy*, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year aklin_co2_norowst, fe
test gdpcapk gdpcap2k

eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year (aklin_co2_norowst = aklin_gdpcap_norowst), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp (aklin_co2_norowst = aklin_gdpcap_norowst), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy* (aklin_co2_norowst = aklin_gdpcap_norowst), fe
test gdpcapk gdpcap2k

eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year (aklin_co2_rowst = aklin_gdpcap_rowst), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp (aklin_co2_rowst = aklin_gdpcap_rowst), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy* (aklin_co2_rowst = aklin_gdpcap_rowst), fe
test gdpcapk gdpcap2k

esttab using "./rr2table3.tex" ///
	,  booktabs label replace ///
 	nodepvars se(2) b(2) ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	substitute(m$ m\\$)	///
	compress nogaps scalars("rmse $\hat{\sigma}$" "N_g $\#$ Countries") r2(2) sfmt(%9.2f %9.0f) ///
	mtitles("FE" "FE" "S-OLS" "2-SLS" "S-2SLS" "S-2SLS" "2-SLS" "S-2SLS" "S-2SLS")	///
	mgroups("Non-Spatial" "Spatial Non-Row-Normalized" "Spatial Row-Normalized", pattern(1 0 1 0 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))	///
	indicate(Year FE = year_dummy*, label($\checkmark$ ))	
eststo clear


*	Estimate the effect
sum gdpcapk if country_aklin == "Mexico" & year == 2000
local mexicoinc2000 = r(mean)
display `mexicoinc2000'
local mexicousimp2000 = 135080

sum gdpcapk if country_aklin == "Canada" & year == 2000
local canadainc2000 = r(mean)
display `canadainc2000'
local canadausimp2000 = 229191

* Reduced form 2-SLS
xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year w_gdp_cap, fe

matrix B = e(b)
di B[1,5]

* When Mexico and Canada's GDP goes up by $1000 and imports go up by $10m
di B[1,5] * 1000 * (`mexicousimp2000' + 1000)
di B[1,5] * 1000 * (`canadausimp2000' + 1000)


*	************************************************************************
*	Table 3
*	************************************************************************

eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy*, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year aklin_co2_norowst_nonoecd, fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year (aklin_co2_norowst_nonoecd = aklin_gdpcap_norowst_nonoecd), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp (aklin_co2_norowst_nonoecd = aklin_gdpcap_norowst_nonoecd), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy* (aklin_co2_norowst_nonoecd = aklin_gdpcap_norowst_nonoecd), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year (aklin_co2_rowst_nonoecd = aklin_gdpcap_rowst_nonoecd), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp (aklin_co2_rowst_nonoecd = aklin_gdpcap_rowst_nonoecd), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy* (aklin_co2_rowst_nonoecd = aklin_gdpcap_rowst_nonoecd), fe
test gdpcapk gdpcap2k

esttab using "./rr2table4.tex"	 ///
	,  booktabs label replace ///
 	nodepvars se(2) b(2) ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	substitute(m$ m\\$)	///
	compress nogaps scalars("rmse $\hat{\sigma}$" "N_g $\#$ Countries") r2(2) sfmt(%9.2f %9.0f) ///
	mtitles("FE" "FE" "S-OLS" "2-SLS" "S-2SLS" "S-2SLS" "2-SLS" "S-2SLS" "S-2SLS")	///
	mgroups("Non-Spatial" "Spatial Non-Row-Normalized" "Spatial Row-Normalized", pattern(1 0 1 0 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))	///
	indicate(Year FE = year_dummy*, label($\checkmark$ ))	
eststo clear


*	************************************************************************
*	4. Matching Tables and Figures: Table 4
*	************************************************************************


preserve
psmatch2 devtreatment gdpcap_1990gkd_maddison rgdsquare_mad gdp_mad polity2 pop_mad_x_polity2 rgdpl2_x_polity rgdpl_x_gdp rgdpl_x_gdp2 lngdpcap lngdpcap_x_gdp lngdpcap_x_polity lnlngdpcap
psbal gdpcapk gdpcap2k gdp_mad polity2 

gen impabcap = impab/pop
label variable impabcap "Imports per Capita"

eststo: reg co2_capita_cdiac impabcap gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp year continent_dummy*, robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 year [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 year continent_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
esttab using "./rrtable2.tex" ///
	, replace r2 booktabs b(3) se(3) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
	mtitles("OLS" "P-Match" "P-Match" "P-Match" "P-Match" "P-Match") ///
	title(Explaining Carbon Trajectories - P-Score Matching Design\label{rrtable2}) ///
	indicate(Year FE = year_dummy*, label($\checkmark$ )) ///
	addnote("Dependent Variable: CO2 per capita." "All P-Match models use weights based on propensity scores, where the balance is based on" "income per capita, its squared term, and democracy.")
eststo clear
restore


*	************************************************************************
*	5. Figure 1
*	************************************************************************

*	Predictions
gen linpred = .
gen sdlinpred = .
gen linpred2 = .
gen sdlinpred2 = .

gen simincome = _n  if _n <= 80

forvalues i = 0(1)80{
quiet xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp, fe
scalar sq = `i'^2
lincom `i'*gdpcapk + sq*gdpcap2k
replace linpred = `r(estimate)' if _n == `i'
replace sdlinpred = `r(se)' if _n == `i'
}

forvalues i = 0(1)80{
quiet xtreg co2_capita_cdiac gdpcapk gdpcap2k w_co2_capita polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp, fe
scalar sq = `i'^2
lincom `i'*gdpcapk + sq*gdpcap2k
replace linpred2 = `r(estimate)' if _n == `i'
replace sdlinpred2 = `r(se)' if _n == `i'
}

gen lb1 = linpred - 1.96*sdlinpred
gen ub1 = linpred + 1.96*sdlinpred

gen lb2 = linpred2 - 1.96*sdlinpred2
gen ub2 = linpred2 + 1.96*sdlinpred2


twoway (rarea ub1 lb1 simincome if simincome <= 40)	///
		(line linpred simincome if simincome <= 40, lwidth(thick))	///
		(rarea ub2 lb2 simincome if simincome <= 40)	///
		(line linpred2 simincome if simincome <= 40, lwidth(thick))	///
			,  yscale(noline) xscale(noline) 	///
			yline(0, lcolor(black)) ///
			title("Predicted Per-Capita Carbon Trajectories", size(6)) ///
			xtitle( "GDP per Capita (k$)", size(4)) ///
			xsca(titlegap(2)) ///
			ysca(titlegap(2)) ///
			ytitle("Carbon Per-Capita Trajectories", size(3)) ///
			graphregion(fcolor(white)) scheme(s2mono)	///
			legend(col(2) order(4 3 2 1) label(2 "When we ignore trade effects") label(1 "95% CI") label(4 "Trade effects included") label(3 "95% CI"))
graph export "./rrgraph5.pdf", replace

		
