*12345678901234567890123456789012345678901234567890123456789012345678901234567890
capture log close
clear all


*	************************************************************************
* 	File-Name: 	AklinEAREAppendix.do
*	Date:  		11/20/2012 (first version); 05/20/2015 (last version)
*	Author: 	Michal Aklin
*	Data Used:  spacedata_v1.dta
*				(via tradematch_spacedata_v1)
*	Purpose:   	.do file to replicate the appendix of:
*				Aklin, Michal. 2015. "Re-exploring the Trade and Environment 
*				Nexus Through the Diffusion of Pollution." Environmental and
*				Resource Economics.
*
*	Note:		This do file should only require few changes (e.g. path to
*				dataset). The tables are listed in the same order as the 
*				appendix.
*				Notice that some of the tables were created based on 
*				Matlab code (see separate matlab file).
*	************************************************************************

*	************************************************************************
*	1. Dataset
*	************************************************************************

*	Change the path as appropriate
use "./AklinEAREData.dta", clear



*	************************************************************************
*	2. Appendix
*	************************************************************************

*	************************************************************************
*	2.1. Matching analysis
*	************************************************************************

*	K = 3
preserve
psmatch2 devtreatment gdpcap_1990gkd_maddison rgdsquare_mad gdp_mad polity2 pop_mad_x_polity2 rgdpl2_x_polity rgdpl_x_gdp rgdpl_x_gdp2 lngdpcap lngdpcap_x_gdp lngdpcap_x_polity lnlngdpcap, neighbor(3)
psbal gdpcapk gdpcap2k gdp_mad polity2 

eststo: reg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5, robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 [aw=_weight], robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5 [aw=_weight], robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5 year_dummy* [aw=_weight], robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5 [aw=_weight], robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5 year_dummy* [aw=_weight], robust
esttab using "./atable6.tex", replace r2 booktabs b(3) se(3) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
mtitles("OLS" "K P-Match" "K P-Match" "K P-Match" "K P-Match" "K P-Match") title(Explaining Carbon Trajectories - 3-Nearest Neighbor Matching Design\label{atable6}) ///
addnote("Dependent Variable: CO2 per capita." "All P-Match models use weights based on propensity scores, where the balance is based on" "income per capita, its squared term, and democracy.")
eststo clear
restore

*	K = 4
preserve
psmatch2 devtreatment gdpcap_1990gkd_maddison rgdsquare_mad gdp_mad polity2 pop_mad_x_polity2 rgdpl2_x_polity rgdpl_x_gdp rgdpl_x_gdp2 lngdpcap lngdpcap_x_gdp lngdpcap_x_polity lnlngdpcap, neighbor(4)
psbal gdpcapk gdpcap2k gdp_mad polity2 

eststo: reg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy*, robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 [aw=_weight], robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5 [aw=_weight], robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5 year_dummy* [aw=_weight], robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5 [aw=_weight], robust
eststo: reg co2_capita_cdiac devtreatment gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy1 continent_dummy2 continent_dummy3 continent_dummy4 continent_dummy5 year_dummy* [aw=_weight], robust
esttab using "./atable7.tex", replace r2 booktabs b(3) se(3) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
mtitles("OLS" "K P-Match" "K P-Match" "K P-Match" "K P-Match" "K P-Match") title(Explaining Carbon Trajectories - 4-Nearest Neighbor Matching Design\label{atable7}) ///
addnote("Dependent Variable: CO2 per capita." "All P-Match models use weights based on propensity scores, where the balance is based on" "income per capita, its squared term, and democracy.")
eststo clear
restore


*	Chile, South Korea, Mexico, and Turkey are listed as industrialized countries
preserve
psmatch2 devtreatment gdpcap_1990gkd_maddison rgdsquare_mad gdp_mad polity2 pop_mad_x_polity2 rgdpl2_x_polity rgdpl_x_gdp rgdpl_x_gdp2 lngdpcap lngdpcap_x_gdp lngdpcap_x_polity lnlngdpcap
psbal gdpcapk gdpcap2k gdp_mad polity2 

eststo: reg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp year continent_dummy*, robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment2 gdpcapk gdpcap2k polity2 year [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment2 gdpcapk gdpcap2k polity2 year continent_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment2 gdpcapk gdpcap2k polity2 continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment2 gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment2 gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
esttab using "./atable9.tex" ///
	, replace r2 booktabs b(3) se(3) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
	mtitles("OLS" "P-Match" "P-Match" "P-Match" "P-Match" "P-Match") ///
	title(P-Score Matching Design - Different Developing Countries\label{atable9}) ///
	addnote("Dependent Variable: CO2 per capita." "All P-Match models use weights based on propensity scores, where the balance is based on" "income per capita, its squared term, and democracy." "Chile, South Korea, Mexico, and Turkey are here coded as industrialized countries.")
eststo clear

*	Controlling for trade openness
preserve
psmatch2 devtreatment gdpcap_1990gkd_maddison rgdsquare_mad gdp_mad polity2 pop_mad_x_polity2 rgdpl2_x_polity rgdpl_x_gdp rgdpl_x_gdp2 lngdpcap lngdpcap_x_gdp lngdpcap_x_polity lnlngdpcap
psbal gdpcapk gdpcap2k gdp_mad polity2 

eststo: reg co2_capita_cdiac openk gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp year continent_dummy*, robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment openk gdpcapk gdpcap2k polity2 year [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment openk gdpcapk gdpcap2k polity2 year continent_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment openk gdpcapk gdpcap2k polity2 continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment openk gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment openk gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
esttab using "./rratable8.tex" ///
	, replace r2 booktabs b(3) se(3) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
	mtitles("OLS" "P-Match" "P-Match" "P-Match" "P-Match" "P-Match") ///
	title(Explaining Carbon Trajectories - Trade Openness\label{rratable8}) ///
	indicate(Year FE = year_dummy*, label($\checkmark$ )) ///
	addnote("Dependent Variable: CO2 per capita." "All P-Match models use weights based on propensity scores, where the balance is based on" "income per capita, its squared term, and democracy.")
eststo clear
restore


*	Matching post 1960
preserve
psmatch2 devtreatment gdpcap_1990gkd_maddison rgdsquare_mad gdp_mad polity2 pop_mad_x_polity2 rgdpl2_x_polity rgdpl_x_gdp rgdpl_x_gdp2 lngdpcap lngdpcap_x_gdp lngdpcap_x_polity lnlngdpcap if year > 1960
psbal gdpcapk gdpcap2k gdp_mad polity2 

eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* year_dummy* [aw=_weight], robust
test gdpcapk gdpcap2k
esttab using "./rratable10.tex" ///
	, replace r2 booktabs b(3) se(3) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
	mtitles("P-Match" "P-Match" "P-Match") ///
	title(Post-1960\label{rratable10}) ///
	indicate(Year FE = year_dummy*, label($\checkmark$ )) ///
	addnote("Dependent Variable: CO2 per capita." )
eststo clear
restore

*	Matching w/o least developped countries
preserve
psmatch2 devtreatment gdpcap_1990gkd_maddison rgdsquare_mad gdp_mad polity2 pop_mad_x_polity2 rgdpl2_x_polity rgdpl_x_gdp rgdpl_x_gdp2 lngdpcap lngdpcap_x_gdp lngdpcap_x_polity lnlngdpcap if ldc == 0
psbal gdpcapk gdpcap2k gdp_mad polity2 

eststo: reg co2_capita_cdiac impabcap gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp year continent_dummy* if ldc == 0, robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 year if ldc == 0 [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 year continent_dummy* if ldc == 0 [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 continent_dummy* year_dummy* if ldc == 0 [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* if ldc == 0 [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac devtreatment impabcap gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* year_dummy* if ldc == 0 [aw=_weight], robust
test gdpcapk gdpcap2k
esttab using "./rratable11.tex" ///
	, replace r2 booktabs b(3) se(3) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
	mtitles("OLS" "P-Match" "P-Match" "P-Match" "P-Match" "P-Match") ///
	title(P-Score Matching Design - Without Least Developed Countries\label{rratable11}) ///
	indicate(Year FE = year_dummy*, label($\checkmark$ )) ///
	addnote("Dependent Variable: CO2 per capita." "All P-Match models use weights based on propensity scores, where the balance is based on" "income per capita, its squared term, and democracy.")
eststo clear
restore

*	Within OECD
preserve
psmatch2 devtreatment gdpcap_1990gkd_maddison rgdsquare_mad gdp_mad polity2 pop_mad_x_polity2 rgdpl2_x_polity rgdpl_x_gdp rgdpl_x_gdp2 lngdpcap lngdpcap_x_gdp lngdpcap_x_polity lnlngdpcap
psbal gdpcapk gdpcap2k gdp_mad polity2 

eststo: reg co2_capita_cdiac impabcap gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp year continent_dummy* if oecd_membership == 1, robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac oecd_real impabcap gdpcapk gdpcap2k polity2 year if oecd_membership == 1 [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac oecd_real impabcap gdpcapk gdpcap2k polity2 year continent_dummy* if oecd_membership == 1 [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac oecd_real impabcap gdpcapk gdpcap2k polity2 continent_dummy* year_dummy* if oecd_membership == 1 [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac oecd_real impabcap gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* if oecd_membership == 1 [aw=_weight], robust
test gdpcapk gdpcap2k
eststo: reg co2_capita_cdiac oecd_real impabcap gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi opec_membership oilcrude_price2007dollar_bp continent_dummy* year_dummy* if oecd_membership == 1 [aw=_weight], robust
test gdpcapk gdpcap2k
esttab using "./rratable12.tex" ///
	, replace r2 booktabs b(3) se(3) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
	mtitles("OLS" "P-Match" "P-Match" "P-Match" "P-Match" "P-Match") ///
	title(Explaining Carbon Trajectories - Within OECD\label{rratable12}) ///
	indicate(Year FE = year_dummy*, label($\checkmark$ )) ///
	addnote("Dependent Variable: CO2 per capita." "All P-Match models use weights based on propensity scores, where the balance is based on" "income per capita, its squared term, and democracy." "Sample restricted to OECD countries." "OECD variable denotes country-years in which country i" "is a member of the OECD.")
eststo clear
restore



*	************************************************************************
*	2.2. Spatial analysis
*	************************************************************************

*	First stage
eststo: xtreg aklin_co2_norowst aklin_gdpcap_norowst gdpcapk gdpcap2k polity2, fe
eststo: xtreg aklin_co2_norowst aklin_gdpcap_norowst gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp, fe
eststo: reg aklin_co2_norowst aklin_gdpcap_norowst gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp country_dummy*, robust
esttab using "./atable8.tex", replace booktabs b(3) se(3) scalars("F F-stat") label star(* 0.10 ** 0.05 *** 0.01) ///
title(Spatial 2-SLS -- First Stage\label{atable8})	///
addnote("Dependent Variable: CO2 per capita.") ///
mtitles("S-2SLS" "S-2SLS" "S-2SLS")
eststo clear


*	Lags
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 laklin_co2_norowst year_dummy*, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 laklin_co2_norowst industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy*, fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year_dummy* (aklin_co2_norowst = laklin_gdpcap_norowst), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year_dummy* industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp (aklin_co2_norowst = laklin_gdpcap_norowst), fe
test gdpcapk gdpcap2k
eststo: ivreg2 co2_capita_cdiac gdpcapk gdpcap2k polity2 year_dummy* industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp country_dummy* (aklin_co2_norowst = laklin_gdpcap_norowst), robust
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year_dummy* (laklin_co2_norowst = laklin_gdpcap_norowst), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year_dummy* industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp (laklin_co2_norowst = laklin_gdpcap_norowst), fe
test gdpcapk gdpcap2k
eststo: ivreg2 co2_capita_cdiac gdpcapk gdpcap2k polity2 year_dummy*  industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp country_dummy* (laklin_co2_norowst = laklin_gdpcap_norowst), robust
test gdpcapk gdpcap2k
esttab using "./atable10.tex", replace booktabs b(3) se(3)  label star(* 0.10 ** 0.05 *** 0.01) ///
title(Various Lags Approaches to Spatial OLS\label{atable10})	///
addnote("Dependent Variable: CO2 per capita.") ///
indicate(Year FE = year_dummy*, label($\checkmark$ )) ///
mtitles("S-OLS" "S-OLS" "2-SLS" "S-2SLS" "S-2SLS" "S-2SLS" "S-2SLS" "S-2SLS")
eststo clear


*	Row normalized
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy*, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year aklin_co2_rowst, fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year (aklin_co2_rowst = aklin_gdpcap_rowst), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp (aklin_co2_rowst = aklin_gdpcap_rowst), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy* (aklin_co2_rowst = aklin_gdpcap_rowst), fe
test gdpcapk gdpcap2k
esttab using "./rratable9.tex", replace booktabs b(3) se(3)  label star(* 0.10 ** 0.05 *** 0.01) ///
	title(Spatial 2-SLS -- Row Normalized\label{rratable9})	///
	addnote("Dependent Variable: CO2 per capita.") ///
	indicate(Year FE = year_dummy*, label($\checkmark$ )) ///
	mtitles("FE" "FE" "S-OLS" "2-SLS" "S-2SLS" "S-2SLS")
eststo clear


*	Reduced form equation of the spatial model
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year aklin_gdpcap_norowst, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp aklin_gdpcap_norowst, fe
test gdpcapk gdpcap2k
eststo: xtreg co2_capita_cdiac gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy* aklin_gdpcap_norowst, fe
test gdpcapk gdpcap2k
esttab using "./rratable13.tex", replace booktabs b(3) se(3)  label star(* 0.10 ** 0.05 *** 0.01) ///
	title(Reduced Form\label{rratable13})	///
	addnote("Dependent Variable: CO2 per capita.") ///
	indicate(Year FE = year_dummy*, label($\checkmark$ )) ///
	mtitles("Reduced Form" "Reduced Form" "Reduced Form" )
eststo clear




*	************************************************************************
*	2.3. Sulfur
*	************************************************************************

eststo: xtreg so2_capita gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp, fe
test gdpcapk gdpcap2k
eststo: xtreg so2_capita gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy*, fe
test gdpcapk gdpcap2k
eststo: xtreg so2_capita gdpcapk gdpcap2k polity2 year w_so2_capita, fe
test gdpcapk gdpcap2k
eststo: xtivreg so2_capita gdpcapk gdpcap2k polity2 year (w_so2_capita = w_gdp_cap), fe
test gdpcapk gdpcap2k
eststo: xtivreg so2_capita gdpcapk gdpcap2k polity2 year industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp (w_so2_capita = w_gdp_cap), fe
test gdpcapk gdpcap2k
eststo: xtivreg so2_capita gdpcapk gdpcap2k polity2 industry_pcgdp_wdi pop pop_density_wdi oilcrude_price2007dollar_bp year_dummy* (w_so2_capita = w_gdp_cap), fe
test gdpcapk gdpcap2k
esttab using "./table5.tex", replace booktabs b(3) se(3)  label star(* 0.10 ** 0.05 *** 0.01) ///
title(Sulfur Dioxide -- Spatial 2-SLS -- Second Stage\label{table5})	///
addnote("Dependent Variable: SO2 per capita.") ///
mtitles("FE" "FE" "S-OLS" "2-SLS" "S-2SLS" "S-2SLS")
eststo clear


*	************************************************************************
*	2.4. Additional Models
*	************************************************************************

*	Distance
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year (aklin_co2_norowst_km = aklin_gdpcap_norowst_km), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year_dummy* (aklin_co2_norowst_km = aklin_gdpcap_norowst_km), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year (aklin_co2_rowst_km = aklin_gdpcap_rowst_km), fe
test gdpcapk gdpcap2k
eststo: xtivreg co2_capita_cdiac gdpcapk gdpcap2k polity2 year_dummy* (aklin_co2_rowst_km = aklin_gdpcap_rowst_km), fe
test gdpcapk gdpcap2k

esttab using "/Users/michaelaklin/Documents/Research/aklin_2011_tradematch/paper/TablesFigures/rr2TableKMWeight.tex" ///
	,  booktabs label replace ///
 	nodepvars se(2) b(2) ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	substitute(m$ m\\$)	///
	compress nogaps scalars("rmse $\hat{\sigma}$" "N_g $\#$ Countries") r2(2) sfmt(%9.2f %9.0f) ///
	mtitles("2-SLS" "S-2SLS" "S-2SLS")	///
	mgroups("Spatial Non-Row-Normalized" "Spatial Row-Normalized", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))	///
	indicate(Year FE = year_dummy*, label($\checkmark$ ))	
eststo clear


*	************************************************************************
*	2.5. Graphs
*	************************************************************************


graph twoway (line so2_capita gdpcapk if country_aklin == "United States of America", legend(lab(1 "US")) lpattern(solid) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "France", legend(lab(2 "France")) lpattern(dash) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "Spain", legend(lab(3 "Spain")) lpattern(dot) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "China", legend(lab(4 "China")) lpattern(dash_dot) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "India", legend(lab(5 "India")) lpattern(longdash) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "Brazil", legend(lab(6 "Brazil")) lpattern(longdash_dot) lwidth(thick))	///
			, ///
			title("Environmental Kuznets Curve - SO2", size(4)) ///
			scheme(s2mono) graphregion(fcolor(white))	///
			saving(graph2, replace)
graph export "./graph2.pdf", replace


*	SO2 and CO2 in the world (I need to pick a country to have a 
*		single time series, so France is randomly chosen)
twoway (tsline norm_world_co2 if country_aklin == "France", legend(lab(1 "CO2"))) ///
		(tsline norm_world_so2 if country_aklin == "France", legend(lab(2 "SO2")))	///
		, 	title("World CO2 and SO2 1900-2007", size(4)) ///
			xtitle( "Year", size(3)) ///
			ytitle("CO2 and SO2 (normalized)", size(3) height(5)) ///
			note("Evolution of world SO2 (sulfur dioxide) and CO2 (carbon dioxide) production." "Normalized to baseline 1950, defined as 100") 	///
			scheme(s2mono) graphregion(fcolor(white))	///
			saving(graph3, replace)
graph export "./graph3.pdf", replace


graph combine graph3.gph graph2.gph	///
			, 	///
			graphregion(fcolor(white)) scheme(s2mono)	///
			title("Sulfur Through Time", size(4)) 
graph export "./graph23.pdf", replace



graph twoway (line co2_capita_cdiac gdpcapk if country_aklin == "United States of America", legend(lab(1 "US")) lpattern(solid) lwidth(thick)) ///
(line co2_capita_cdiac gdpcapk if country_aklin == "France", legend(lab(2 "France")) lpattern(dash) lwidth(thick)) ///
(line co2_capita_cdiac gdpcapk if country_aklin == "Spain", legend(lab(3 "Spain")) lpattern(dot) lwidth(thick)) ///
(line co2_capita_cdiac gdpcapk if country_aklin == "China", legend(lab(4 "China")) lpattern(dash_dot) lwidth(thick)) ///
(line co2_capita_cdiac gdpcapk if country_aklin == "India", legend(lab(5 "India")) lpattern(longdash) lwidth(thick)) ///
(line co2_capita_cdiac gdpcapk if country_aklin == "Brazil", legend(lab(6 "Brazil")) lpattern(longdash_dot) lwidth(thick))	///
			, ///
			title("Environmental Kuznets Curve - CO2", size(4)) ///
			scheme(s2mono) graphregion(fcolor(white))	///
			saving(graph1, replace)
graph export "./graph1.pdf", replace


graph twoway (line so2_capita gdpcapk if country_aklin == "United States of America", legend(lab(1 "US")) lpattern(solid) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "France", legend(lab(2 "France")) lpattern(dash) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "Spain", legend(lab(3 "Spain")) lpattern(dot) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "China", legend(lab(4 "China")) lpattern(dash_dot) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "India", legend(lab(5 "India")) lpattern(longdash) lwidth(thick)) ///
(line so2_capita gdpcapk if country_aklin == "Brazil", legend(lab(6 "Brazil")) lpattern(longdash_dot) lwidth(thick))	///
			, ///
			title("Environmental Kuznets Curve - SO2", size(4)) ///
			scheme(s2mono) graphregion(fcolor(white))	///
			saving(graph2, replace)
graph export "./graph2.pdf", replace


graph combine graph1.gph graph2.gph	///
			, 	///
			graphregion(fcolor(white)) scheme(s2mono)	///
			title("Environmental Kuznets Curve", size(4)) ///
			note("The line connects countries from year to year.")
graph export "./graph12.pdf", replace


